API
===

Sijax
-----

.. autoclass:: sijax.Sijax.Sijax
   :members:


.. _available-response-methods:

BaseResponse
------------

.. autoclass:: sijax.response.BaseResponse.BaseResponse
   :members:


StreamingIframeResponse
-----------------------

.. autoclass:: sijax.response.StreamingIframeResponse.StreamingIframeResponse
   :show-inheritance:
   :members:


Helpers
-------

.. autofunction:: sijax.helper.init_static_path


Comet plugin
------------

.. autofunction:: sijax.plugin.comet.register_comet_callback
.. autofunction:: sijax.plugin.comet.register_comet_object
.. autoclass:: sijax.plugin.comet.CometResponse.CometResponse
   :show-inheritance:
   :members:


Upload plugin
-------------

.. autofunction:: sijax.plugin.upload.register_upload_callback

.. autoclass:: sijax.plugin.upload.UploadResponse.UploadResponse
   :show-inheritance:
   :members:

